Découvrez le réseau des médiathèques de Val Parisis Agglo

Val Parisis Agglo

Découvrez le réseau des médiathèques de Val Parisis Agglo

Venez découvrir notre réseau de 8 médiathèques et ses nombreuses collections. Des lieux de partage pour lire, jouer, découvrir, travailler, écouter et échanger.
Le portail des médiathèques : http://mediatheques.valparisis.fr/
Le site de Val Parisis : http://www.valparisis.fr/
Pour plus d'informations, consultez le guide du lecteur : https://fr.calameo.com/read/004646940372d834da27b
Crédits musique :
PACIFIC SUN by Nicolai Heidlas Music https://soundcloud.com/nicolai-heidlas
Creative Commons — Attribution 3.0 Unported— CC BY 3.0
http://creativecommons.org/licenses/b...
Music provided by Audio Library https://youtu.be/kbqmEJTr3nU

03/04/2017